package com.aucma.base.mapper;

import java.util.List;
import com.aucma.base.domain.BaseCustomData;

/**
 * 自定义数据维护Mapper接口
 * 
 * @author Yinq
 * @date 2023-11-08
 */
public interface BaseCustomDataMapper 
{
    /**
     * 查询自定义数据维护
     * 
     * @param objId 自定义数据维护主键
     * @return 自定义数据维护
     */
    public BaseCustomData selectBaseCustomDataByObjId(Long objId);

    /**
     * 查询自定义数据维护列表
     * 
     * @param baseCustomData 自定义数据维护
     * @return 自定义数据维护集合
     */
    public List<BaseCustomData> selectBaseCustomDataList(BaseCustomData baseCustomData);

    /**
     * 新增自定义数据维护
     * 
     * @param baseCustomData 自定义数据维护
     * @return 结果
     */
    public int insertBaseCustomData(BaseCustomData baseCustomData);

    /**
     * 修改自定义数据维护
     * 
     * @param baseCustomData 自定义数据维护
     * @return 结果
     */
    public int updateBaseCustomData(BaseCustomData baseCustomData);

    /**
     * 删除自定义数据维护
     * 
     * @param objId 自定义数据维护主键
     * @return 结果
     */
    public int deleteBaseCustomDataByObjId(Long objId);

    /**
     * 批量删除自定义数据维护
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBaseCustomDataByObjIds(Long[] objIds);
}
